@@ -70,7 +70,7 @@ from json import JSONDecodeError
 
 import cbor2
 from shapely import geometry
-from namespace import NtvType, Namespace, str_type
+from json_ntv.namespace import NtvType, Namespace, str_type
 
 class Ntv(ABC):
     ''' The Ntv class is an abstract class used for all NTV entities.
